==> am_mod_lbr_0_3.zip: am_mod_lbr_0_3/components/lbr/language/1/barnraiser_01/set_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/lbr_common.inc.php');


// HEADER
$lang['hdr_set'] = 									"wiki set";
$lang['hdr_permissions'] = 							"permissions";
$lang['hdr_starting_a_set'] = 						"creating your wiki set";
$lang['hdr_page_default'] = 						"set default page";
$lang['hdr_ownership'] = 							"resign editorship";
$lang['hdr_tags'] = 								"tags";


// SUBMIT BUTTONS
$lang['sub_update'] =                            	"save";
$lang['sub_default_page_id'] = 						"set default page";
$lang['sub_resign'] = 								"resign editorship";


// SETUP - used to make initial wiki page
$lang['create_page_title'] = 						"home page";
$lang['create_page_name'] = 						"WikiHomePage"; // must be studly caps!
$lang['create_page_synopsis'] = 					"This wiki page has not yet been made";


// ERROR MESSAGES
$lang['error']['title_empty'] = 					"You have not given a title to your wiki set.";
$lang['error']['synopsis_empty'] = 					"You have not given a synopsis to your wiki set.";


// BODY TEXT
$lang['txt_image'] = 								"images";
$lang['txt_none'] = 								"none";
$lang['txt_title'] = 								"title";
$lang['txt_synopsis'] = 							"synopsis";
$lang['txt_publish'] = 								"publish";
$lang['txt_language'] = 							"language";
$lang['txt_wiki_set_create_intro'] =				"Once you create your wiki set you will be taken to the default page which will include information to help you start editing the first page of your wiki set";
$lang['txt_status'] = 								"status";
$lang['txt_owner_intro'] = 							"You are the wiki set editor in chief. As the editor in chief you edit the wiki-set and elect coordinators. You can hand over your role to another sub editor at any time and demote yourself to a sub coordinator role.";
$lang['txt_new_owner'] = 							"new editor in chief";
$lang['txt_tags'] = 								"tags";
$lang['txt_participation'] = 						"participation";
$lang['txt_my_identity'] =							"my identity";

?>

==> am_mod_lbr_0_6.zip: am_mod_lbr_0_6/components/lbr/language/1/barnraiser_01/set_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once('inc/lbr_common.inc.php');


// HEADER
$lang['hdr_set'] = 									"wiki set";
$lang['hdr_starting_a_set'] = 						"creating your wiki set";
$lang['hdr_page_default'] = 						"set default page";
$lang['hdr_ownership'] = 							"resign editorship";
$lang['hdr_tags'] = 								"tags";


// SUBMIT BUTTONS
$lang['sub_update'] =                            	"save";
$lang['sub_default_page_id'] = 						"set default page";
$lang['sub_resign'] = 								"resign editorship";


// SETUP - used to make initial wiki page
$lang['create_page_title'] = 						"home page";
$lang['create_page_name'] = 						"WikiHomePage"; // must be studly caps!
$lang['create_page_synopsis'] = 					"This wiki page has not yet been edited";


// ERROR MESSAGES
$lang['error']['title_empty'] = 					"You have not given a title to your wiki set.";
$lang['error']['synopsis_empty'] = 					"You have not given a synopsis to your wiki set.";


// HREF
$lang['href_stylesheet'] = 							"stylesheet editor";


// BODY TEXT
$lang['txt_image'] = 								"images";
$lang['txt_none'] = 								"none";
$lang['txt_title'] = 								"title";
$lang['txt_synopsis'] = 							"synopsis";
$lang['txt_publish'] = 								"publish";
$lang['txt_language'] = 							"language";
$lang['txt_wiki_set_create_intro'] =				"Once you create your wiki set you will be taken to the default page which will include information to help you start editing the first page of your wiki set";
$lang['txt_status'] = 								"status";
$lang['txt_owner_intro'] = 							"You are the wiki set editor in chief. As the editor in chief you edit the wiki-set and elect coordinators. You can hand over your role to another sub editor at any time and demote yourself to a sub coordinator role.";
$lang['txt_new_owner'] = 							"new editor in chief";
$lang['txt_tags'] = 								"tags";
$lang['txt_participation'] = 						"participation";
$lang['txt_my_identity'] =							"my identity";

$lang['txt_file_to_upload'] = 						"file";
$lang['txt_file_to_upload_name'] = 					"filename";
$lang['txt_title_intro'] = 							"describe your wiki";
$lang['txt_title_permissions'] = 					"set permissions for the wiki";
$lang['txt_title_image'] = 							"add a thumbnail image to your wiki";
$lang['txt_title_save'] = 							"check and save your wiki";

?>
